.. segyio documentation master file, created by
   sphinx-quickstart on Sat Mar 17 18:42:51 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

********************
segyio documentation
********************


API reference
=============
.. toctree::
   :maxdepth: 3

   segyio
   tutorials/index.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
